#!/usr/bin/env python
"""
Command line interface (CLI) for easydarts
"""

import argparse
import pkg_resources
from easydarts.cli.calibration import cli_command_calibration


try:
	version = pkg_resources.require("easydarts")[0].version
except Exception:
	version = '[error]'


def main():
    #
	# Arguments parser
	#


    parser = argparse.ArgumentParser(
		prog='easydarts',
		description='command line interface for easydarts')


	#
	# Options
	#


    parser.add_argument(
		'-v', '--version', 
		action='version', version='easydarts %s' % version)


	#
	# -> Commands
	#


    commands = parser.add_subparsers(
		help='',
		dest='command', metavar='<commands>')


    #
    # -> Commands -> Calibrate
    #


    calibration_parser = commands.add_parser(
		'calibrate', 
		help='starts calibration process')


    # ------------------------------------

    args = vars(parser.parse_args())
    command = args.get('command')

    if command == 'calibrate': cli_command_calibration(args)
    else: parser.print_help()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="easydarts",
    version="0.0.1",
    description="Steel darts calibration and score recognition system",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    author="Cidevant Von Goethe",
    author_email="cidevant@mail.ru",
    url="https://github.com/easydarts/easydarts",
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'easydarts = easydarts.cli.cli:main',
        ]
    },
    install_requires=[
		'opencv-python',
        'numpy',
        'matplotlib'
    ],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
    ],
    python_requires='>=3.6',
)
